==> huaweicloudsdkworkspaceapp-3.1.134-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/list_task_execute_detail_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListTaskExecuteDetailRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'execute_history_id': 'str',
        'offset': 'int',
        'limit': 'int'
    }

    attribute_map = {
        'execute_history_id': 'execute_history_id',
        'offset': 'offset',
        'limit': 'limit'
    }

    def __init__(self, execute_history_id=None, offset=None, limit=None):
        """ListTaskExecuteDetailRequest

        The model defined in huaweicloud sdk

        :param execute_history_id: 定时任务唯一标识。
        :type execute_history_id: str
        :param offset: 查询的偏移量。
        :type offset: int
        :param limit: 查询的数量，值区间[1-100]。
        :type limit: int
        """
        
        

        self._execute_history_id = None
        self._offset = None
        self._limit = None
        self.discriminator = None

        self.execute_history_id = execute_history_id
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit

    @property
    def execute_history_id(self):
        """Gets the execute_history_id of this ListTaskExecuteDetailRequest.

        定时任务唯一标识。

        :return: The execute_history_id of this ListTaskExecuteDetailRequest.
        :rtype: str
        """
        return self._execute_history_id

    @execute_history_id.setter
    def execute_history_id(self, execute_history_id):
        """Sets the execute_history_id of this ListTaskExecuteDetailRequest.

        定时任务唯一标识。

        :param execute_history_id: The execute_history_id of this ListTaskExecuteDetailRequest.
        :type execute_history_id: str
        """
        self._execute_history_id = execute_history_id

    @property
    def offset(self):
        """Gets the offset of this ListTaskExecuteDetailRequest.

        查询的偏移量。

        :return: The offset of this ListTaskExecuteDetailRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListTaskExecuteDetailRequest.

        查询的偏移量。

        :param offset: The offset of this ListTaskExecuteDetailRequest.
        :type offset: int
        """
        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this ListTaskExecuteDetailRequest.

        查询的数量，值区间[1-100]。

        :return: The limit of this ListTaskExecuteDetailRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListTaskExecuteDetailRequest.

        查询的数量，值区间[1-100]。

        :param limit: The limit of this ListTaskExecuteDetailRequest.
        :type limit: int
        """
        self._limit = limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListTaskExecuteDetailRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspaceapp-3.1.156-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/list_task_execute_detail_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListTaskExecuteDetailRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'execute_history_id': 'str',
        'offset': 'int',
        'limit': 'int'
    }

    attribute_map = {
        'execute_history_id': 'execute_history_id',
        'offset': 'offset',
        'limit': 'limit'
    }

    def __init__(self, execute_history_id=None, offset=None, limit=None):
        r"""ListTaskExecuteDetailRequest

        The model defined in huaweicloud sdk

        :param execute_history_id: 定时任务唯一标识。
        :type execute_history_id: str
        :param offset: 查询的偏移量。
        :type offset: int
        :param limit: 查询的数量，值区间[1-100]。
        :type limit: int
        """
        
        

        self._execute_history_id = None
        self._offset = None
        self._limit = None
        self.discriminator = None

        self.execute_history_id = execute_history_id
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit

    @property
    def execute_history_id(self):
        r"""Gets the execute_history_id of this ListTaskExecuteDetailRequest.

        定时任务唯一标识。

        :return: The execute_history_id of this ListTaskExecuteDetailRequest.
        :rtype: str
        """
        return self._execute_history_id

    @execute_history_id.setter
    def execute_history_id(self, execute_history_id):
        r"""Sets the execute_history_id of this ListTaskExecuteDetailRequest.

        定时任务唯一标识。

        :param execute_history_id: The execute_history_id of this ListTaskExecuteDetailRequest.
        :type execute_history_id: str
        """
        self._execute_history_id = execute_history_id

    @property
    def offset(self):
        r"""Gets the offset of this ListTaskExecuteDetailRequest.

        查询的偏移量。

        :return: The offset of this ListTaskExecuteDetailRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        r"""Sets the offset of this ListTaskExecuteDetailRequest.

        查询的偏移量。

        :param offset: The offset of this ListTaskExecuteDetailRequest.
        :type offset: int
        """
        self._offset = offset

    @property
    def limit(self):
        r"""Gets the limit of this ListTaskExecuteDetailRequest.

        查询的数量，值区间[1-100]。

        :return: The limit of this ListTaskExecuteDetailRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        r"""Sets the limit of this ListTaskExecuteDetailRequest.

        查询的数量，值区间[1-100]。

        :param limit: The limit of this ListTaskExecuteDetailRequest.
        :type limit: int
        """
        self._limit = limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListTaskExecuteDetailRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
